@@ -53,7 +53,7 @@ sub source {
     my $rule_target = qr/(?:$rule_altern|'$rule_altern'|"$rule_altern")/;
 
     $self->tag('no-dh-sequencer')
-      unless $contents =~ /^[^:]+:[^ \t]*\n\t+dh[ \t]+$rule_target/m
+      unless $contents =~ /^[^:]+:[^ \t]*\n\t+(\+|@|-)?dh[ \t]+$rule_target/m
       || $contents =~ m{^\s*include\s+/usr/share/cdbs/1/class/hlibrary.mk\s*$}m
       || $contents =~ m{\bDEB_CABAL_PACKAGE\b};
 
